# Calcul du débit d'une passe à macro-rugosité

Le calcul du débit d'une passe à macro-rugosité correspond à l'implémentation de l'algorithme et des équations présentent dans
*Cassan L, Laurens P. 2016. Design of emergent and submerged rock-ramp fish passes. Knowl. Manag. Aquat. Ecosyst., 417, 45*.

## Principe général du calcul


La limite entre le cas émergent et le cas submergé se situe à \(h = 1.1 \times k\).

## Cas submergé

Le calcul du débit se fait par itérations successives qui consistent à trouver la valeur de débit permettant d'obtenir l'égalite entre la vitesse moyenne du lit donnée par&nbsp;:

$$u_0 = \sqrt{2 g S D (1 - \sigma C)/(C_d C)}$$

et la vitesse moyenne du lit donnée par intégration des débits entre et au-dessus des blocs&nbsp;:

$$\bar{u} = \frac{Q_{inf} + Q_{sup}}{k}$$

avec respectivement \(Q_{inf}\) et \(Q_{sup}\) les débits unitaires pour la partie dans la canopée et la partie au dessus de la canopée.

### Calcul du débit unitaire *Q<sub>inf</sub>* dans la canopée

Le débit dans la canopée est obtenu par intégration du profil de vitesse (Eq. 9, Cassan et al., 2016)&nbsp:

$$Q_{inf} = \int_{0}^1 u(\tilde{z}) d \tilde{z}$$

avec

$$u(\tilde{z}) = u_0 \sqrt{\beta \left( \frac{h}{k} -1 \right) \frac{\sinh(\beta \tilde{z})}{\cosh(\beta)} + 1}$$

avec

$$\beta = \sqrt{(k / \alpha_t)(C_d C k / D)/(1 - \sigma C)}$$

avec \(\sigma = 1\) pour \(C_{d0} = 2\), \(\sigma = \pi/4\) sinon

et \(\alpha_t\) obtenu à partir de la résolution de l'équation suivante :

$$\alpha_t u(1) - l_0 u_* = 0$$

avec

$$l_0 = \min \left( s, 0.15 k \right)$$

avec

$$s = D \left( \frac{1}{\sqrt{C}} - 1 \right)$$

### Calcul du débit unitaire *Q<sub>sup</sub>* au dessus de la canopée

$$Q_{sup} = \int_k^h u(z) dz$$

avec (Eq. 12, Cassan et al., 2016)

$$u(z) = \frac{u_*}{\kappa} \ln \left( \frac{z - d}{z_0} \right) - 1 $$

avec (Eq. 14, Cassan et al., 2016)

$$z_0 = (k - d) \exp \left( {\frac{-\kappa u_k}{u_*}} \right)$$

et (Eq. 13, Cassan et al., 2016)

$$ d =  k - \frac{\alpha_t u_k}{\kappa u_*}$$

ce qui donne

$$Q_{sup} = \frac{u_*}{\kappa} \left( (h - d) \left( \ln \left( \frac{h-d}{z_0} \right) - 1\right)  - \left( (k - d) \left( \ln \left( \frac{k-d}{z_0} \right) - 1 \right) \right) \right)$$

## Cas émergent

Le calcul du débit se fait par itérations successives qui consistent à trouver la valeur de débit permettant d'obtenir l'égalité entre la vitesse apparente \(V\) et la vitesse moyenne du lit donnée par&nbsp;:

$$u_0 = \sqrt{\frac{2 g S D (1 - \sigma C)}{C_d C (1 + N)}}$$

avec

$$C_d = C_{d0} (1 + 0.4 / h_*^2) f_F(F)$$

$$N = \frac{\alpha C_f}{C_d C h_*}$$

avec

$$\alpha = 1 - (a_y / a_x \times C)$$

## Formules utilisées

### Vitesse débitante *V*

$$V = \frac{Q}{B \times h}$$

### Vitesse entre les blocs *V<sub>g</sub>*

$$V_g = \frac{V}{1 - \sqrt{(a_x/a_y)C}}$$

### Froude *F*

$$F = \frac{V_g}{\sqrt{gh}}$$

### Fonction de correction du coefficient de trainée liée au Froude *f<sub>F</sub>(F)*

Si \(F < 1.3\) (Eq. 5, Cassan et al., 2016)

$$f_F(F) = \mathrm{min} \left( \frac{0.4 C_{d0} + 0.7}{1- (F^2 / 4)}, \frac{1}{F^{\frac{2}{3}}} \right)$$

sinon

$$f_F(F) = F^{\frac{-4}{3}}$$

### Coefficient de friction du lit *C<inf>f</inf>*

Si \(k_s < 10^{-6} \mathrm{m}\) alors

$$C_f = 0.3164 / 4 * Re^{-0.25}$$

avec

$$Re = u_0 \times h / \nu$$

Sinon (Eq. 3, Cassan et al., 2016)

$$C_f = \frac{2}{(5.1 \mathrm{log} (h/k_s)+6)^2}$$

### Vitesse de cisaillement *u<sub>&ast;</sub>*

$$u_* = \sqrt{gS(h-k)}$$

## Notations

- \(\alpha\) : ratio de l'aire concernée par la friction du lits sur \(a_x \times a_y\)
- \(\alpha_t\) : échelle de longueur de la turbulence dans la couche des blocs(m)
- \(\beta\) : ratio entre la contrainte due à la trainée et la contrainte due aux turbulences
- \(\kappa\) : constante de Von Karman = 0.41
- \(\sigma\) : ratio entre l'aire du block dans le plan X,y et \(D^2\)
- \(a_x\) :  largeur d'une cellule (perpendiculaire à l'écoulement) (m)
- \(a_y\) :  longueur d'une cellule (parallèle à l'écoulement) (m)
- \(B\) : largeur de la passe (m)
- \(C\) : concentration de blocs
- \(C_d\) : coefficient de trainée d'un bloc dans les conditions d'écoulement actuel
- \(C_{d0}\) : coefficient de trainée d'un bloc considérant un bloc infiniment haut avec \(F \ll 1\)
- \(C_f)\) : coefficient de friction du lit
- \(d\) : déplacement dans le plan zéro du profil logarithmique (m)
- \(D\) : largeur du bloc face à l'écoulement (m)
- \(F\) : nombre de Froude basé sur \(h\) et \(V_g\)
- \(g\) : accélération de la gravité = 9.81 m.s<sup>-2</sup>
- \(h\) : profondeur moyenne (m)
- \(h_*\) : profondeur adimensionnelle (\(h / D\))
- \(k\) : hauteur utile des blocs (m)
- \(k_s\) : hauteur de la rugosité (m)
- \(l_0\) : échelle de longueur de la turbulence au sommet des blocs (m)
- \(N\) : ratio entre la friction du lit et la force de trainée
- \(Q\) : débit (m<sup>3</sup>/s)
- \(S\) : pente de la passe (m/m)
- \(u_0\) : vitesse moyenne dans le lit (m/s)
- \(u_*\) : vitesse de cisaillement (m/s)
- \(V\) : vitesse débitante (m/s)
- \(V_g\) : vitesse entre les blocs (m/s)
- \(s\) : distance minimale entre les blocs (m)
- \(z\) : position verticale (m)
- \(z_0\) : rugosité hydraulique (m)
- \(\tilde{z}\) : position verticale adimensionnelle \(\tilde{z} = z / k\)
