import { ListPage } from "./list.po";
import { CalculatorPage } from "./calculator.po";
import { Navbar } from "./navbar.po";
import { browser, by, element } from "protractor";
import { AppPage } from "./app.po";
import { SideNav } from "./sidenav.po";

/**
 * Clone calculators
 */
describe("ngHyd − Passe à Bassins", () => {
  let startPage: AppPage;
  let listPage: ListPage;
  let calcPage: CalculatorPage;
  let navbar: Navbar;
  let sidenav: SideNav;

  beforeEach(() => {
    startPage = new AppPage();
    listPage = new ListPage();
    calcPage = new CalculatorPage();
    navbar = new Navbar();
    sidenav = new SideNav();
  });

  describe("create PAB - ", async () => {

    it("when PAB is created after Cloisons & ParallelStructure", async() => {
      // create Cloisons
      await startPage.navigateTo();
      await listPage.clickMenuEntryForCalcType(10);
      // create ParallelStructure
      await navbar.clickNewCalculatorButton();
      await listPage.clickMenuEntryForCalcType(8);
      // create PAB
      await navbar.clickNewCalculatorButton();
      await listPage.clickMenuEntryForCalcType(15);
      // check number of basins
      const innerFieldsets = element.all(by.css(".fieldset-inner"));
      expect(await innerFieldsets.count()).toBe(1);
      // check <select> value
      const smc = calcPage.getSelectById("select_modele_cloisons");
      const v = await calcPage.getSelectValueText(smc);
      expect(v).toEqual("Cloisons");
      // check downstream wall
      const smca = calcPage.getSelectById("select_modele_cloison_aval");
      expect(await calcPage.getSelectValueText(smca)).toEqual("Ouvrages");
    });

    it("when PAB is created before Cloisons & ParallelStructure", async() => {
      // create PAB
      await startPage.navigateTo();
      await listPage.clickMenuEntryForCalcType(15);
      // create Cloisons
      await navbar.clickNewCalculatorButton();
      await listPage.clickMenuEntryForCalcType(10);
      // create ParallelStructure
      await navbar.clickNewCalculatorButton();
      await listPage.clickMenuEntryForCalcType(8);
      // check number of basins
      await navbar.clickCalculatorTab(0);
      const innerFieldsets = element.all(by.css(".fieldset-inner"));
      expect(await innerFieldsets.count()).toBe(1);
      // check <select> value
      const smc = calcPage.getSelectById("select_modele_cloisons");
      const v = await calcPage.getSelectValueText(smc);
      expect(v).toEqual("Cloisons");
      // check downstream wall
      const smca = calcPage.getSelectById("select_modele_cloison_aval");
      expect(await calcPage.getSelectValueText(smca)).toEqual("Ouvrages");
    });

  });

  describe("generate PAB - ", async () => {

    it("from a Cloisons among many", async() => {
      // create many Cloisons
      await startPage.navigateTo();
      await listPage.clickMenuEntryForCalcType(10);
      await navbar.clickNewCalculatorButton();
      await listPage.clickMenuEntryForCalcType(10);
      await navbar.clickNewCalculatorButton();
      await listPage.clickMenuEntryForCalcType(10);
      // choose one of them and change its parameters
      await navbar.clickCalculatorTab(1);
      const Z1 = calcPage.getInputById("Z1");
      await Z1.clear();
      await Z1.sendKeys("114");
      const LB = calcPage.getInputById("LB");
      await LB.clear();
      await LB.sendKeys("11.5");
      const DH = calcPage.getInputById("DH");
      await DH.clear();
      await DH.sendKeys("0.72");
      // create PAB from it, changing modal parameters
      const genButton = calcPage.getGeneratePabButton();
      await genButton.click();
      const debit = calcPage.getInputById("generatePabDebit");
      expect(await debit.getAttribute("value")).toBe("1.5");
      await debit.clear();
      // send "1.6" in 3 movements, because "." triggers an error and Angular can't cope with the subsequent keys
      await debit.sendKeys("1");
      await browser.sleep(300);
      await debit.sendKeys(".");
      await browser.sleep(300);
      await debit.sendKeys("6");
      await browser.sleep(300);
      const coteAmont = calcPage.getInputById("generatePabCoteAmont");
      expect(await coteAmont.getAttribute("value")).toBe("114");
      await coteAmont.clear();
      await coteAmont.sendKeys("115");
      const nbBassins = calcPage.getInputById("generatePabNbBassins");
      expect(await nbBassins.getAttribute("value")).toBe("6");
      await nbBassins.clear();
      await nbBassins.sendKeys("5");
      // click "Generate"
      await element(by.css("dialog-generate-pab button#do-generate")).click();
      await browser.sleep(1000);
      // check parameters values
      const P_Q = calcPage.getInputById("Q");
      expect(await P_Q.getAttribute("value")).toBe("1.6");
      const P_Z2 = calcPage.getInputById("Z2");
      expect(await P_Z2.getAttribute("value")).toBe("111.4");
      // check number of basins
      const innerFieldsets = element.all(by.css(".fieldset-inner"));
      expect(await innerFieldsets.count()).toBe(5);
      // check <select> values
      innerFieldsets.each(async (inf) => {
        const smc = inf.element(by.css("mat-select#select_modele_cloisons"));
        expect(await calcPage.getSelectValueText(smc)).toEqual("Cloisons 1");
      });
    });

  });

  describe("load session files - ", async () => {

    it("when PAB is loaded after Cloisons & ParallelStructure", async() => {
      await startPage.navigateTo();
      // load
      await navbar.clickMenuButton();
      await browser.sleep(200);
      await sidenav.clickLoadSessionButton();
      await browser.sleep(200);
      await sidenav.loadSessionFile("./session-pab.json");
      await browser.sleep(500);
      // check existence of the loaded modules
      expect(await navbar.getAllCalculatorTabs().count()).toBe(6);
      // check parameters values
      await navbar.clickCalculatorTab(5);
      await browser.sleep(700); // sometime fails because of tabs order @see nghyd#197
      const P_Q = calcPage.getInputById("Q");
      expect(await P_Q.getAttribute("value")).toBe("1.533");
      const P_Z2 = calcPage.getInputById("Z2");
      expect(await P_Z2.getAttribute("value")).toBe("99.44");
      // check number of basins
      const innerFieldsets = element.all(by.css(".fieldset-inner"));
      expect(await innerFieldsets.count()).toBe(5);
      // check <select> and QA values
      const expectedCloisons = [ "Cloisons 1", "Cloisons 2", "Cloisons", "Cloisons 2", "Cloisons 1" ];
      const expectedQA = [ 2, 1, 3, 5, 4 ];
      for (let i = 0; i < innerFieldsets.length; i++) {
        const inf = innerFieldsets[i];
        const smc = inf.element(by.css("mat-select#select_modele_cloisons"));
        expect(await calcPage.getSelectValueText(smc)).toEqual(expectedCloisons[i]);
        const QA = inf.element(by.css("input[id$=QA]"));
        expect(Number(await QA.getAttribute("value"))).toBe(expectedQA[i]);
        i++;
      }
      // check downstream wall
      const smca = calcPage.getSelectById("select_modele_cloison_aval");
      expect(await calcPage.getSelectValueText(smca)).toEqual("Ouvrages 1");
    });

    it("when PAB is loaded before Cloisons & ParallelStructure", async() => {
      await startPage.navigateTo();
      // load
      await navbar.clickMenuButton();
      await browser.sleep(200);
      await sidenav.clickLoadSessionButton();
      await browser.sleep(200);
      await sidenav.loadSessionFile("./session-pab-mauvais-ordre.json");
      await browser.sleep(500);
      // check existence of the loaded modules
      expect(await navbar.getAllCalculatorTabs().count()).toBe(6);
      // check parameters values
      await navbar.clickCalculatorTab(0);
      await browser.sleep(200);
      const P_Q = calcPage.getInputById("Q");
      expect(await P_Q.getAttribute("value")).toBe("1.533");
      const P_Z2 = calcPage.getInputById("Z2");
      expect(await P_Z2.getAttribute("value")).toBe("99.44");
      // check number of basins
      const innerFieldsets = element.all(by.css(".fieldset-inner"));
      expect(await innerFieldsets.count()).toBe(5);
      // check <select> values
      const expectedCloisons = [ "Cloisons 1", "Cloisons 2", "Cloisons", "Cloisons 2", "Cloisons 1" ];
      const expectedQA = [ 2, 1, 3, 5, 4 ];
      let i = 0;
      for (let i = 0; i < innerFieldsets.length; i++) {
        const inf = innerFieldsets[i];
        const smc = inf.element(by.css("mat-select#select_modele_cloisons"));
        expect(await calcPage.getSelectValueText(smc)).toEqual(expectedCloisons[i]);
        const QA = inf.element(by.css("input[id$=QA]"));
        expect(Number(await QA.getAttribute("value"))).toBe(expectedQA[i]);
        i++;
      }
      // check downstream wall
      const smca = calcPage.getSelectById("select_modele_cloison_aval");
      expect(await calcPage.getSelectValueText(smca)).toEqual("Ouvrages 1");
    });

    it("when PAB is loaded without Cloisons & ParallelStructure", async() => {
      await startPage.navigateTo();
      // load
      await navbar.clickMenuButton();
      await browser.sleep(200);
      await sidenav.clickLoadSessionButton();
      await browser.sleep(200);
      await sidenav.loadSessionFile("./session-pab-modeles-vides.json");
      await browser.sleep(500);

      // check existence of the loaded modules
      expect(await navbar.getAllCalculatorTabs().count()).toBe(1);
      // check number of basins
      await navbar.clickCalculatorTab(0);
      await browser.sleep(200);
      const innerFieldsets = element.all(by.css(".fieldset-inner"));
      expect(await innerFieldsets.count()).toBe(3);
      // check empty <select>
      innerFieldsets.each(async (inf) => {
        const smc = inf.element(by.css("mat-select#select_modele_cloisons"));
        const smcEmpty = await calcPage.isSelectEmpty(smc);
        console.log("SMC EMPTY ?", smcEmpty);
        expect(smcEmpty).toBe(true);
      });
      // check empty <select> for downstream wall
      const smca = calcPage.getSelectById("select_modele_cloison_aval");
      expect(await calcPage.isSelectEmpty(smca)).toBe(true);

      // create a Cloisons
      await navbar.clickNewCalculatorButton();
      await listPage.clickMenuEntryForCalcType(10);
      // create a ParallelStructure
      await navbar.clickNewCalculatorButton();
      await listPage.clickMenuEntryForCalcType(8);
      // check that they are selected
      await navbar.clickCalculatorTab(0);
      innerFieldsets.each(async (inf) => {
        const smc = inf.element(by.css("mat-select#select_modele_cloisons"));
        expect(await calcPage.getSelectValueText(smc)).toEqual("Cloisons");
      });
      const smca2 = calcPage.getSelectById("select_modele_cloison_aval");
      expect(await calcPage.getSelectValueText(smca2)).toEqual("Ouvrages");
    });

  });

});
