import { Session } from "jalhyd";
import { SelectEntry } from "./select-entry";
import { FieldSet } from "./fieldset";
import { SelectFieldModel } from "./select-field-model";

/**
 * A select field that populates itself with references to
 * available ParallelStructure modules (used by PAB)
 */
export class SelectFieldModelCloisonAval extends SelectFieldModel {

    protected initSelectedValue() {
        if (this.parent instanceof FieldSet) {
            const mc = this.parent.nub.properties.getPropValue("modeleCloisonAval");
            if (mc) {
                this._selectedEntry = new SelectEntry(mc, {});
            } // else if current model is undefined, do not select it so that default ParallelStructures will be chosen (if available)
        }
    }

    /**
     * Populates entries with available ParallelStructures
     */
    protected populate() {
        const psNubs = Session.getInstance().getParallelStructureNubs();
        for (const cl of psNubs) {
            const e = new SelectEntry(cl.uid, cl);
            this.addEntry(e);
        }
    }
}
